@@ -1186,6 +1186,12 @@ pref("editor.positioning.offset",            0);
 pref("dom.max_chrome_script_run_time", 20);
 pref("dom.max_script_run_time", 10);
 
+// How long a plugin is allowed to process a synchronous IPC message
+// before we consider it "hung".
+//
+//  NB: chosen to match dom.max_script_run_time by default
+pref("dom.ipc.plugins.timeoutSecs", 10);
+
 pref("svg.enabled", true);
 pref("svg.smil.enabled", false);
 
@@ -1221,18 +1227,18 @@ pref("font.minimum-size.x-western", 0);
 pref("font.minimum-size.x-unicode", 0);
 pref("font.minimum-size.x-user-def", 0);
 
-//@line 1654 "/builds/slave/firefox-lorentz-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 1660 "/builds/slave/firefox-lorentz-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 1656 "/builds/slave/firefox-lorentz-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 1662 "/builds/slave/firefox-lorentz-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 // Mac specific preference defaults
 pref("browser.drag_out_of_frame_style", 1);
 pref("ui.key.saveLink.shift", false); // true = shift, false = meta
 pref("ui.click_hold_context_menus", false);
 
-//@line 1662 "/builds/slave/firefox-lorentz-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 1668 "/builds/slave/firefox-lorentz-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 // whether to always use ATSUI for text even if CoreText is available
 pref("gfx.force_atsui_text", false);
-//@line 1665 "/builds/slave/firefox-lorentz-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 1671 "/builds/slave/firefox-lorentz-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
 // default fonts (in UTF8 and using canonical names)
 // to determine canonical font names, use a debug build and 
@@ -1644,21 +1650,21 @@ pref("ui.panel.default_level_parent", false);
 
 pref("mousewheel.system_scroll_override_on_root_content.enabled", false);
 
-//@line 2078 "/builds/slave/firefox-lorentz-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2084 "/builds/slave/firefox-lorentz-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2281 "/builds/slave/firefox-lorentz-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2287 "/builds/slave/firefox-lorentz-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2377 "/builds/slave/firefox-lorentz-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2383 "/builds/slave/firefox-lorentz-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2652 "/builds/slave/firefox-lorentz-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2658 "/builds/slave/firefox-lorentz-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2720 "/builds/slave/firefox-lorentz-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2726 "/builds/slave/firefox-lorentz-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2746 "/builds/slave/firefox-lorentz-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2752 "/builds/slave/firefox-lorentz-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2766 "/builds/slave/firefox-lorentz-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2772 "/builds/slave/firefox-lorentz-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2774 "/builds/slave/firefox-lorentz-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2780 "/builds/slave/firefox-lorentz-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
 // Login Manager prefs
 pref("signon.rememberSignons",              true);
@@ -1695,9 +1701,9 @@ pref("image.cache.timeweight", 500);
 // The default Accept header sent for images loaded over HTTP(S)
 pref("image.http.accept", "image/png,image/*;q=0.8,*/*;q=0.5");
 
-//@line 2816 "/builds/slave/firefox-lorentz-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2822 "/builds/slave/firefox-lorentz-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2821 "/builds/slave/firefox-lorentz-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2827 "/builds/slave/firefox-lorentz-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
 // Enable/Disable the geolocation API for content
 pref("geo.enabled", true);
