@@ -5,6 +5,11 @@ pref("security.enable_ssl3",             true);
 pref("security.enable_tls",		 true);
 pref("security.enable_tls_session_tickets", true);
 
+pref("security.ssl.allow_unrestricted_renego_everywhere__temporarily_available_pref", true);
+pref("security.ssl.renego_unrestricted_hosts", "");
+pref("security.ssl.treat_unsafe_negotiation_as_broken", false);
+pref("security.ssl.require_safe_negotiation",  false);
+
 pref("security.ssl2.rc4_128", false);
 pref("security.ssl2.rc2_128", false);
 pref("security.ssl2.des_ede3_192", false);
@@ -22,14 +27,14 @@ pref("security.ssl3.rsa_1024_des_cbc_sha", false);
 pref("security.ssl3.rsa_rc4_40_md5", false);
 pref("security.ssl3.rsa_rc2_40_md5", false);
 // Camellia is broken on Windows CE for now, see bug 508113
-//@line 26 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/netwerk/base/public/security-prefs.js"
+//@line 31 "/builds/slave/firefox-lorentz-macosx-xulrunner/build/netwerk/base/public/security-prefs.js"
 pref("security.ssl3.dhe_rsa_camellia_256_sha", true);
 pref("security.ssl3.dhe_dss_camellia_256_sha", true);
 pref("security.ssl3.rsa_camellia_256_sha", true);
 pref("security.ssl3.dhe_rsa_camellia_128_sha", true);
 pref("security.ssl3.dhe_dss_camellia_128_sha", true);
 pref("security.ssl3.rsa_camellia_128_sha", true);
-//@line 33 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/netwerk/base/public/security-prefs.js"
+//@line 38 "/builds/slave/firefox-lorentz-macosx-xulrunner/build/netwerk/base/public/security-prefs.js"
 pref("security.ssl3.dhe_rsa_aes_256_sha", true);
 pref("security.ssl3.dhe_dss_aes_256_sha", true);
 pref("security.ssl3.rsa_aes_256_sha", true);
