@@ -1,17 +1,6 @@
 function closeWindow(aClose, aPromptFunction)
 {
-  var windowCount = 0;
-  var wm = Components.classes["@mozilla.org/appshell/window-mediator;1"]
-                     .getService(Components.interfaces.nsIWindowMediator);
-  var e = wm.getEnumerator(null);
-  
-  while (e.hasMoreElements()) {
-    var w = e.getNext();
-    if (++windowCount == 2) 
-      break;
-  }
-
-//@line 21 "/builds/slave/191-osx-xr/build/toolkit/content/globalOverlay.js"
+//@line 30 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/toolkit/content/globalOverlay.js"
     if (typeof(aPromptFunction) == "function" && !aPromptFunction())
       return false;
 
@@ -68,7 +57,8 @@ function goUpdateCommand(aCommand)
     goSetCommandEnabled(aCommand, enabled);
   }
   catch (e) {
-    dump("An error occurred updating the " + aCommand + " command\n");
+    Components.utils.reportError("An error occurred updating the " +
+                                 aCommand + " command: " + e);
   }
 }
 
@@ -81,7 +71,8 @@ function goDoCommand(aCommand)
       controller.doCommand(aCommand);
   }
   catch (e) {
-    dump("An error occurred executing the " + aCommand + " command\n" + e + "\n");
+    Components.utils.reportError("An error occurred executing the " +
+                                 aCommand + " command: " + e);
   }
 }
 
@@ -161,11 +152,6 @@ function visitLink(aEvent) {
     protocolSvc.loadUrl(uri);
 }
 
-function isValidLeftClick(aEvent, aName)
-{
-  return (aEvent.button == 0 && aEvent.originalTarget.localName == aName);
-}
-
 function setTooltipText(aID, aTooltipText)
 {
   var element = document.getElementById(aID);
@@ -173,23 +159,6 @@ function setTooltipText(aID, aTooltipText)
     element.setAttribute("tooltiptext", aTooltipText);
 }
 
-function FillInTooltip ( tipElement )
-{
-  var retVal = false;
-  var textNode = document.getElementById("TOOLTIP-tooltipText");
-  if (textNode) {
-    while (textNode.hasChildNodes())
-      textNode.removeChild(textNode.firstChild);
-    var tipText = tipElement.getAttribute("tooltiptext");
-    if (tipText) {
-      var node = document.createTextNode(tipText);
-      textNode.appendChild(node);
-      retVal = true;
-    }
-  }
-  return retVal;
-}
-
 __defineGetter__("NS_ASSERT", function() {
   delete this.NS_ASSERT;
   var tmpScope = {};
