@@ -1,4 +1,4 @@
-//@line 37 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/toolkit/content/macWindowMenu.js"
+//@line 37 "/builds/slave/firefox-lorentz-macosx-xulrunner/build/toolkit/content/macWindowMenu.js"
 
 function checkFocusedWindow()
 {
@@ -20,6 +20,9 @@ function checkFocusedWindow()
 
 function toOpenWindow( aWindow )
 {
+  // deminiaturize the window, if it's in the Dock
+  if (aWindow.windowState == STATE_MINIMIZED)
+    aWindow.restore();
   aWindow.document.commandDispatcher.focusedWindow.focus();
 }
 
